@@ -16,15 +16,15 @@ def get_word_vec(*args):
     return WordVec(*args)
 
 
-emo_of_description_file = data_dir / "emoji_joined.tsv"
+emo_of_description_file = data_dir / 'emoji_joined.tsv'
 
-tokenizer = re.compile(r"\w+").findall
+tokenizer = re.compile(r'\w+').findall
 
 
 def mk_emo_of_description():
     return dict(
         np.genfromtxt(
-            str(emo_of_description_file), delimiter="\t", dtype=str, skip_header=1
+            str(emo_of_description_file), delimiter='\t', dtype=str, skip_header=1
         )
     )
 
