@@ -6,8 +6,10 @@ except ImportError:
     try:
         from importlib_resources import files  # pip install importlib_resources
     except ModuleNotFoundError:
-        raise ModuleNotFoundError("No module named 'importlib_resources'. "
-                                  "pip install importlib_resources or conda install importlib_resources")
+        raise ModuleNotFoundError(
+            "No module named 'importlib_resources'. "
+            'pip install importlib_resources or conda install importlib_resources'
+        )
 
 root_path = files('moji')
 data_dir = root_path / 'data'
